'use strict';

/* eslint-env mocha */

var assert = require('chai').assert;
var Button = require('./button');
var React = require('react');
var ReactDOM = require('react-dom');
var TestUtils = require('react-addons-test-utils');

describe('Button', function () {

  it('renders a button', function () {
    var tree = TestUtils.renderIntoDocument(React.createElement(
      Button,
      null,
      React.createElement('child', null)
    ));
    var node = ReactDOM.findDOMNode(tree);
    assert.equal(node.tagName, 'BUTTON');
  });

  it('has the button class', function () {
    var tree = TestUtils.renderIntoDocument(React.createElement(
      Button,
      null,
      React.createElement('child', null)
    ));
    var node = ReactDOM.findDOMNode(tree);
    assert.equal(node.classList.contains('pl-button'), true);
  });

  it('does something when clicked', function (done) {
    var tree = TestUtils.renderIntoDocument(React.createElement(
      Button,
      {
        onClick: function onClick() {
          done();
        } },
      React.createElement('child', null)
    ));
    TestUtils.Simulate.click(ReactDOM.findDOMNode(tree));
  });

  it('can be disabled', function () {
    var tree = TestUtils.renderIntoDocument(React.createElement(
      Button,
      { isDisabled: true },
      React.createElement('child', null)
    ));
    var node = ReactDOM.findDOMNode(tree);
    assert.equal(node.classList.contains('pl-disabled'), true);
  });

  it('can be made small', function () {
    var tree = TestUtils.renderIntoDocument(React.createElement(
      Button,
      { isSmall: true },
      React.createElement('child', null)
    ));
    var node = ReactDOM.findDOMNode(tree);
    assert.equal(node.classList.contains('pl-small'), true);
  });

  it('can be secondary', function () {
    var tree = TestUtils.renderIntoDocument(React.createElement(
      Button,
      { isSecondary: true },
      React.createElement('child', null)
    ));
    var node = ReactDOM.findDOMNode(tree);
    assert.equal(node.classList.contains('pl-secondary'), true);
  });
});