'use strict';

var React = require('react');
var ReactDOM = require('react-dom');
var classNames = require('classnames');

var Button = require('./button');
var Icon = require('./icon');

var buttonPropTypes = Object.assign({}, Button.propTypes);
delete buttonPropTypes.onClick;

var Dropdown = React.createClass({
  displayName: 'Dropdown',


  propTypes: Object.assign(buttonPropTypes, {
    children: React.PropTypes.node,
    isRight: React.PropTypes.bool,
    items: React.PropTypes.array.isRequired,
    onChange: React.PropTypes.func.isRequired,
    selectedIndex: React.PropTypes.oneOfType([React.PropTypes.number, React.PropTypes.arrayOf(React.PropTypes.number)])
  }),

  getInitialState: function getInitialState() {
    return {
      isOpen: false
    };
  },

  _onButtonClick: function _onButtonClick() {
    if (this.props.items.length > 1) {
      this.setState({ isOpen: true });
      document.body.addEventListener('click', this._onBodyClick);
    }
  },

  _onItemClick: function _onItemClick(index, item) {
    this.props.onChange(index, item);
  },

  _onBodyClick: function _onBodyClick(event) {
    if (!Array.isArray(this.props.selectedIndex) || !ReactDOM.findDOMNode(this).contains(event.target)) {
      this.setState({ isOpen: false });
      document.body.removeEventListener('click', this._onBodyClick);
    }
  },

  render: function render() {
    var dropdownClassName = classNames('pl-dropdown', this.props.className, {
      'pl-open': this.state.isOpen,
      'pl-right': this.props.isRight,
      'pl-optionless': this.props.items.length === 1
    });
    return React.createElement(
      'div',
      { className: dropdownClassName },
      React.createElement(
        Button,
        { isPrimary: this.props.isPrimary,
          isSecondary: this.props.isSecondary,
          isSmall: this.props.isSmall,
          onClick: this._onButtonClick },
        React.createElement(
          'span',
          null,
          this.props.children || this.props.items[this.props.selectedIndex]
        ),
        React.createElement(Icon, { name: 'chevron_down' })
      ),
      React.createElement(
        'div',
        { className: 'pl-dropdown-items' },
        this.props.items.map(function (item, index) {
          var itemClassName = classNames('pl-dropdown-item', {
            'pl-selected': Array.isArray(this.props.selectedIndex) ? this.props.selectedIndex.indexOf(index) !== -1 : index === this.props.selectedIndex
          });
          return React.createElement(
            'div',
            { className: itemClassName,
              key: index,
              onClick: this._onItemClick.bind(null, index, item) },
            item
          );
        }, this)
      )
    );
  }
});

module.exports = Dropdown;