'use strict';

/* eslint-env mocha */

var assert = require('chai').assert;
var React = require('react');
var ReactDOM = require('react-dom');
var TestUtils = require('react-addons-test-utils');

var Overlay = require('./overlay');

describe('Overlay', function () {

  it('renders a .pl-overlay', function () {
    var tree = TestUtils.renderIntoDocument(React.createElement(
      Overlay,
      null,
      React.createElement('child', null)
    ));
    var node = ReactDOM.findDOMNode(tree);
    assert.equal(node.classList.contains('pl-overlay'), true);
  });

  it('can have custom classes', function () {
    var tree = TestUtils.renderIntoDocument(React.createElement(
      Overlay,
      { className: 'test' },
      React.createElement('child', null)
    ));
    var node = ReactDOM.findDOMNode(tree);
    assert.equal(node.classList.contains('test'), true);

    // arrays work too
    tree = TestUtils.renderIntoDocument(React.createElement(
      Overlay,
      { className: ['foo', 'bar'] },
      React.createElement('child', null)
    ));
    node = ReactDOM.findDOMNode(tree);
    assert.equal(node.classList.contains('foo'), true);
  });

  it('onDimClick callback gets called when the overlay dim is clicked', function (done) {
    var tree = TestUtils.renderIntoDocument(React.createElement(
      Overlay,
      { onDimClick: function onDimClick() {
          return done();
        } },
      React.createElement('child', null)
    ));
    var dim = TestUtils.findRenderedDOMComponentWithClass(tree, 'pl-overlay-dim');
    TestUtils.Simulate.click(dim);
  });
});