'use strict';

/* eslint-env mocha */

var assert = require('chai').assert;
var React = require('react');
var ReactDOM = require('react-dom');
var TestUtils = require('react-addons-test-utils');

var Toggle = require('./toggle');

describe('Toggle', function () {

  it('renders a checkbox', function () {
    var tree = TestUtils.renderIntoDocument(React.createElement(Toggle, { isToggled: true, onToggle: function onToggle() {} }));
    var checkbox = TestUtils.findAllInRenderedTree(tree, function (el) {
      return el.type === 'checkbox';
    });
    assert.equal(checkbox.length, 1);
  });

  it('sets the name attribute on the checkbox', function () {
    var tree = TestUtils.renderIntoDocument(React.createElement(Toggle, { isToggled: true, name: 'test', onToggle: function onToggle() {} }));
    var checkbox = TestUtils.findAllInRenderedTree(tree, function (el) {
      return el.type === 'checkbox';
    });
    assert.equal(checkbox[0].name, 'test');
  });

  it('executes onToggle callback when clicked', function (done) {
    var tree = TestUtils.renderIntoDocument(React.createElement(Toggle, { isToggled: true, onToggle: function onToggle() {
        done();
      } }));
    TestUtils.Simulate.click(ReactDOM.findDOMNode(tree));
  });

  it('renders a label', function () {
    var tree = TestUtils.renderIntoDocument(React.createElement(Toggle, { isToggled: true, label: 'test', onToggle: function onToggle() {} }));
    var checkbox = TestUtils.findAllInRenderedTree(tree, function (el) {
      return el.tagName === 'LABEL';
    });
    assert.equal(checkbox[0].innerText, 'test');
  });
});